Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1352)

Unified Diff: chrome/browser/prefs/pref_model_associator.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/test_extension_service.cc ('k') | chrome/browser/prefs/pref_model_associator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/pref_model_associator.h
diff --git a/chrome/browser/prefs/pref_model_associator.h b/chrome/browser/prefs/pref_model_associator.h
index 22ad33c555998570f936aa3d12b7863f21106005..21e3fddd097a1ea5384b754b7e69e6e6e22665cd 100644
--- a/chrome/browser/prefs/pref_model_associator.h
+++ b/chrome/browser/prefs/pref_model_associator.h
@@ -29,22 +29,23 @@ class Value;
// TODO(sync): Merge this into PrefService once we separate the profile
// PrefService from the local state PrefService.
class PrefModelAssociator
- : public SyncableService,
+ : public csync::SyncableService,
public base::NonThreadSafe {
public:
PrefModelAssociator();
virtual ~PrefModelAssociator();
- // SyncableService implementation.
- virtual SyncDataList GetAllSyncData(syncable::ModelType type) const OVERRIDE;
- virtual SyncError ProcessSyncChanges(
+ // csync::SyncableService implementation.
+ virtual csync::SyncDataList GetAllSyncData(
+ syncable::ModelType type) const OVERRIDE;
+ virtual csync::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const SyncChangeList& change_list) OVERRIDE;
- virtual SyncError MergeDataAndStartSyncing(
+ const csync::SyncChangeList& change_list) OVERRIDE;
+ virtual csync::SyncError MergeDataAndStartSyncing(
syncable::ModelType type,
- const SyncDataList& initial_sync_data,
- scoped_ptr<SyncChangeProcessor> sync_processor,
- scoped_ptr<SyncErrorFactory> sync_error_factory) OVERRIDE;
+ const csync::SyncDataList& initial_sync_data,
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor,
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory) OVERRIDE;
virtual void StopSyncing(syncable::ModelType type) OVERRIDE;
// Returns the list of preference names that are registered as syncable, and
@@ -84,7 +85,7 @@ class PrefModelAssociator
// provided.
static bool CreatePrefSyncData(const std::string& name,
const base::Value& value,
- SyncData* sync_data);
+ csync::SyncData* sync_data);
// Extract preference value and name from sync specifics.
base::Value* ReadPreferenceSpecifics(
@@ -94,7 +95,7 @@ class PrefModelAssociator
protected:
friend class ProfileSyncServicePreferenceTest;
- typedef std::map<std::string, SyncData> SyncDataMap;
+ typedef std::map<std::string, csync::SyncData> SyncDataMap;
// Create an association for a given preference. If |sync_pref| is valid,
// signifying that sync has data for this preference, we reconcile their data
@@ -104,9 +105,9 @@ class PrefModelAssociator
// Note: We do not modify the sync data for preferences that are either
// controlled by policy (are not user modifiable) or have their default value
// (are not user controlled).
- void InitPrefAndAssociate(const SyncData& sync_pref,
+ void InitPrefAndAssociate(const csync::SyncData& sync_pref,
const std::string& pref_name,
- SyncChangeList* sync_changes);
+ csync::SyncChangeList* sync_changes);
static base::Value* MergeListValues(
const base::Value& from_value, const base::Value& to_value);
@@ -141,11 +142,11 @@ class PrefModelAssociator
// The PrefService we are syncing to.
PrefService* pref_service_;
- // Sync's SyncChange handler. We push all our changes through this.
- scoped_ptr<SyncChangeProcessor> sync_processor_;
+ // Sync's csync::SyncChange handler. We push all our changes through this.
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor_;
// Sync's error handler. We use this to create sync errors.
- scoped_ptr<SyncErrorFactory> sync_error_factory_;
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory_;
DISALLOW_COPY_AND_ASSIGN(PrefModelAssociator);
};
« no previous file with comments | « chrome/browser/extensions/test_extension_service.cc ('k') | chrome/browser/prefs/pref_model_associator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698